"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Static = Static;
exports.Relative = Relative;
exports.Absolute = Absolute;
exports.Fixed = Fixed;
exports.Sticky = Sticky;
var tslib_1 = require("tslib");
var clsx_1 = tslib_1.__importDefault(require("clsx"));
var react_1 = tslib_1.__importDefault(require("react"));
var utils_1 = require("../utils");
var Box_1 = require("../Box");
var Direction;
(function (Direction) {
    Direction["INSET"] = "inset";
    Direction["Y"] = "inset-y";
    Direction["X"] = "inset-x";
    Direction["LEFT"] = "left";
    Direction["RIGHT"] = "right";
    Direction["TOP"] = "top";
    Direction["BOTTOM"] = "bottom";
})(Direction || (Direction = {}));
function PositionBase(props) {
    var className = props.className, position = props.position, zIndex = props.zIndex, inset = props.inset, x = props.x, y = props.y, top = props.top, bottom = props.bottom, left = props.left, right = props.right, boxProps = tslib_1.__rest(props, ["className", "position", "zIndex", "inset", "x", "y", "top", "bottom", "left", "right"]);
    // TODO: Support responsive
    var positionDirectionClassNames = resolveClassName({
        inset: inset,
        x: x,
        y: y,
        top: top,
        bottom: bottom,
        left: left,
        right: right,
    });
    return (react_1.default.createElement(Box_1.Box, tslib_1.__assign({ className: (0, clsx_1.default)((0, utils_1.responsive)(utils_1.resolveValue, position), positionDirectionClassNames, (0, utils_1.responsive)(utils_1.resolveValue, zIndex), className) }, boxProps)));
}
function Static(props) {
    return react_1.default.createElement(PositionBase, tslib_1.__assign({ position: "static" }, props));
}
function Relative(props) {
    return react_1.default.createElement(PositionBase, tslib_1.__assign({ position: "relative" }, props));
}
function Absolute(props) {
    return react_1.default.createElement(PositionBase, tslib_1.__assign({ position: "absolute" }, props));
}
function Fixed(props) {
    return react_1.default.createElement(PositionBase, tslib_1.__assign({ position: "fixed" }, props));
}
function Sticky(props) {
    return react_1.default.createElement(PositionBase, tslib_1.__assign({ position: "sticky" }, props));
}
function getClassName(dir, value) {
    if (value == null) {
        return '';
    }
    var isNegative = (typeof value === 'number' && value < 0) ||
        (typeof value === 'string' && value[0] === '-');
    var normalizedValue = typeof value === 'number' ? Math.abs(value) : value.substring(1);
    var className = "".concat(dir, "-").concat(normalizedValue);
    return isNegative ? "-".concat(className) : className;
}
function resolveClassName(direction) {
    if ('inset' in direction) {
        return getClassName(Direction.INSET, direction.inset);
    }
    // Always resolve to the most specific
    var top = 'y' in direction ? direction.y : direction.top;
    var bottom = 'y' in direction ? direction.y : direction.bottom;
    var left = 'x' in direction ? direction.x : direction.left;
    var right = 'x' in direction ? direction.x : direction.right;
    if (top === bottom && left === right && top === left) {
        return getClassName(Direction.INSET, top);
    }
    var classNames = [];
    if (top === bottom) {
        classNames.push(getClassName(Direction.Y, top));
    }
    else {
        classNames.push(getClassName(Direction.TOP, top), getClassName(Direction.BOTTOM, bottom));
    }
    if (left === right) {
        classNames.push(getClassName(Direction.X, left));
    }
    else {
        classNames.push(getClassName(Direction.LEFT, left), getClassName(Direction.RIGHT, right));
    }
    return (0, clsx_1.default)(classNames);
}
//# sourceMappingURL=Position.js.map