"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveMargin = resolveMargin;
var tslib_1 = require("tslib");
var clsx_1 = tslib_1.__importDefault(require("clsx"));
var spacing_1 = require("./spacing");
function getClassName(_a) {
    var direction = _a.direction, scale = _a.scale;
    if (scale == null) {
        return '';
    }
    if (scale === '-px' || (scale !== 'px' && scale < 0)) {
        return "-".concat(spacing_1.Prefix.MARGIN).concat(direction, "-px");
    }
    return "".concat(spacing_1.Prefix.MARGIN).concat(direction, "-").concat(scale);
}
function resolveMargin(spacing) {
    if (typeof spacing === 'number' || typeof spacing === 'string') {
        return getClassName({
            direction: spacing_1.Direction.ALL,
            scale: spacing,
        });
    }
    // Always resolve to the most specific
    var top = 'y' in spacing ? spacing.y : spacing.top;
    var bottom = 'y' in spacing ? spacing.y : spacing.bottom;
    var left = 'x' in spacing ? spacing.x : spacing.left;
    var right = 'x' in spacing ? spacing.x : spacing.right;
    if (top === bottom && left === right && top === left) {
        return getClassName({
            direction: spacing_1.Direction.ALL,
            scale: top,
        });
    }
    var classNames = [];
    if (top === bottom) {
        classNames.push(getClassName({
            direction: spacing_1.Direction.Y,
            scale: top,
        }));
    }
    else {
        classNames.push(getClassName({
            direction: spacing_1.Direction.TOP,
            scale: top,
        }), getClassName({
            direction: spacing_1.Direction.BOTTOM,
            scale: bottom,
        }));
    }
    if (left === right) {
        classNames.push(getClassName({
            direction: spacing_1.Direction.X,
            scale: left,
        }));
    }
    else {
        classNames.push(getClassName({
            direction: spacing_1.Direction.LEFT,
            scale: left,
        }), getClassName({
            direction: spacing_1.Direction.RIGHT,
            scale: right,
        }));
    }
    return (0, clsx_1.default)(classNames);
}
//# sourceMappingURL=margin.js.map